@@ -85,7 +85,7 @@ def exception_handler(exc, context):
         # 401
         code = ComCodeChoice.UNAUTHORIZED_ERR
     elif isinstance(exc, MethodNotAllowed):
-        code = ComCodeChoice.MethodNotAllowed
+        code = ComCodeChoice.HTTP_405_METHOD_NOT_ALLOWED
     elif isinstance(exc, PermissionDenied):
         # 403
         code = ComCodeChoice.FORBIDDEN_ERR
